# dokku-ansible-deploy

## Overview

Deploy applications on Dokku using Ansible.

When we package and deploy applications with Dokku, we still have a number of
manual tasks to complete before the application is production ready. Running
Dokku host side commands such as `dokku letsencrypt`, creating and linking
database stores and even going ahead and wiring up monitoring and alerting
infrastructure.

This plugin automates what would be otherwise manual steps. Once you `git push`
your application deployment, this plugin consumes configuration specified in
the `deploy.d` directory to carry out the end-to-end production deployment
steps.

A rough overview of the feature set is:

- Setup your entire application configuration in a set of easy to manage YAML file
- Encrypt secrets in your Git repository and have them decrypted during deployment
- Custom hooks are available to drop into running an Ansible playbook for advanced users
- Compatible with both Heroku buildpack and Docker deployments

More documentation coming soon TM.

## Example Usage

- [keycloak](https://git.autonomic.zone/autonomic-cooperative/keycloak)
- [gitea](https://git.autonomic.zone/autonomic-cooperative/gitea)

## Requirements

- dokku 0.19.13+
- Debian based system (uses `apt` package manager for installing dependencies)

## Installation

```bash
$ dokku plugin:install https://git.autonomic.zone/autonomic-cooperative/dokku-ansible-deploy.git
$ dokku ansible-deploy:sudo-pass
```

## Per-app Host Setup

```bash
$ dokku ansible-deploy:vault-pass myapp
```
